@@ -56,7 +56,7 @@ use ReadonlyX;
 use Scalar::Util qw( reftype blessed );
 use Time::Local;
 use Time::HiRes qw( gettimeofday tv_interval );
-use URI::Encode qw(uri_encode);
+use URL::Encode qw(url_encode);
 use XML::Simple;
 
 Readonly::Scalar my $DEFAULT_REGION   => 'us-east-1';
@@ -112,7 +112,7 @@ __PACKAGE__->mk_accessors(
   )
 );
 
-our $VERSION = '2.0.9'; ## no critic (RequireInterpolationOfMetachars)
+our $VERSION = '2.0.10'; ## no critic (RequireInterpolationOfMetachars)
 
 our @EXPORT_OK = qw(
   create_urlencoded_content
@@ -1416,10 +1416,8 @@ sub create_urlencoded_content {
     push @args, 'Version', $version;
   }
 
-  return join $AMPERSAND, map {
-    sprintf '%s=%s', $_->[0],
-      uri_encode( $_->[1], { encode_reserved => $TRUE } )
-  } pairs @args;
+  return join $AMPERSAND,
+    map { sprintf '%s=%s', $_->[0], url_encode( $_->[1] ) } pairs @args;
 }
 
 ########################################################################
@@ -1795,6 +1793,12 @@ Then...
 
 =head1 DESCRIPTION
 
+=begin markdown
+
+[![amazon-api](https://github.com/rlauer6/perl-Amazon-API/actions/workflows/build.yml/badge.svg)](https://github.com/rlauer6/perl-Amazon-API/actions/workflows/build.yml)
+
+=end markdown
+
 Generic class for constructing AWS API interfaces. Typically used as a
 parent class, but can be used directly. This package can also
 generates stubs for Amazon APIs using the Botocore project's
@@ -2779,7 +2783,7 @@ response.
 
 =head1 VERSION
 
-This documentation refers to version 2.0.9 of C<Amazon::API>.
+This documentation refers to version 2.0.10 of C<Amazon::API>.
 
 =head1 DIAGNOSTICS
 
