@@ -6,11 +6,11 @@ use warnings;
 use parent qw(Exporter);
 
 use Amazon::API::Constants qw(:booleans :chars);
-use Amazon::API::Template qw(:all);
+use Amazon::API::Template  qw(:all);
 
 use Carp;
 use Data::Dumper;
-use English qw(-no_match_vars);
+use English    qw(-no_match_vars);
 use List::Util qw( pairs any );
 use ReadonlyX;
 use Scalar::Util qw(reftype blessed );
@@ -34,7 +34,7 @@ our %EXPORT_TAGS = ( all => [@EXPORT_OK] );
 Readonly::Scalar our $SHAPE_NAME_TEMPLATE =>
   'Amazon::API::Botocore::Shape::%s::%s';
 
-our $VERSION = '2.0.9'; ## no critic (RequireInterpolationOfMetachars)
+our $VERSION = '2.0.10'; ## no critic (RequireInterpolationOfMetachars)
 
 our $TEMPLATE_START = tell DATA;
 
@@ -46,7 +46,7 @@ sub create_module_name {
   my $module_name;
 
   if ( length $service == 3 ) {
-    $module_name = uc $service; # SQS SNS IAM STS SES RDS...
+    $module_name = uc $service;  # SQS SNS IAM STS SES RDS...
   }
   else {
     # Route53, Cloudwatch? SecretsManager? ...well then provide your own damn name!
@@ -109,7 +109,7 @@ sub snake_case {
 ########################################################################
   my ($name) = @_;
 
-  while ( $name =~ s/([[:upper:]])([[:lower:]])/lc("_$1").$2/xsme ) { }; # snake_case the CamelCase
+  while ( $name =~ s/([[:upper:]])([[:lower:]])/lc("_$1").$2/xsme ) { };  # snake_case the CamelCase
 
   $name =~ s/^_//xsm;
 
@@ -251,7 +251,7 @@ sub param_n {
 ########################################################################
   my ( $message, $prefix, $idx ) = @_;
 
-  if ( !defined $idx ) { # first call, check args
+  if ( !defined $idx ) {  # first call, check args
     croak 'message argument must be reference'
       if !ref $message;
   }
@@ -430,7 +430,13 @@ sub new {
   my ( $class, $value ) = @_;
 
   my $options = $SHAPE_DEFINITION;
+  my $type = $options->{type};
 
+  # may have to initialize other types (list?) as well
+  if ( ! $value && $type eq 'structure' ) {
+    $value = {};
+  }
+  
   $options->{_value} = $value;
   $options->{service} = '@service@';
   
